import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_masked_text/flutter_masked_text.dart';
import 'package:http/http.dart' as http;

import '../../usuario/usuario-model.dart';
import '../../usuario/usuario-service.dart';
import '../../../const.dart';

class UrlFoto {
  final String url;

  UrlFoto({@required this.url});

  factory UrlFoto.fromJson(Map<String, dynamic> json) {
    return UrlFoto(url: json['url']);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['url'] = this.url;
    return data;
  }
}

class CorpoHome extends StatefulWidget {
  final UsuarioModel user;

  const CorpoHome({Key key, this.user}) : super(key: key);

  @override
  CorpoHomeState createState() {
    return CorpoHomeState();
  }
}

class CorpoHomeState extends State<CorpoHome> {
  UsuarioService service = new UsuarioService();

  Future<UrlFoto> pegarFoto;

  @override
  void initState() {
    pegarFoto = urlFoto();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(
          horizontal: MediaQuery.of(context).size.width * 0.025,
          vertical: MediaQuery.of(context).size.height * 0.015),
      //color: Colors.grey,
      child: Column(
        children: <Widget>[
          //fotoPerfil(),
          dadosIniciais(),
        ],
      ),
    );
  }

  Widget fotoPerfil(String dado) {
    return FutureBuilder(
        future: pegarFoto,
        builder: (context, snapshot) {
          if (snapshot.hasError) {
            return Center(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Icon(
                    Icons.face_outlined,
                    size: 100,
                  ),
                  Text(
                    'Sem foto!',
                    style: TextStyle(fontSize: 25),
                  )
                ],
              ),
            );
          } else if (snapshot.hasData) {
            return Container(
              height: MediaQuery.of(context).size.height * 0.255,
              width: MediaQuery.of(context).size.width * 0.35,
              child: Image.network(
                  'https://sis.sig.uema.br/' + snapshot.data.url.toString(),
                  fit: BoxFit.cover),
            );
          } else {
            return CircularProgressIndicator();
          }
        });
  }

  Future<UrlFoto> urlFoto() async {
    UsuarioModel user = new UsuarioModel();
    final response = await http.get(
        'https://sis.sig.uema.br/sigaa/resgatarFotoUsuario?cpf=${widget.user.cpf}');

    if (response.statusCode == 200) {
      return UrlFoto.fromJson(jsonDecode(response.body));
    } else {
      throw Exception('Failed to load album');
    }
  }

  Widget dadosIniciais() {
    var maskeredCpf = MaskedTextController(
        mask: '000.000.000-00',
        text: "${widget.user.cpf.toString().padLeft(11, "0")}");
    DateTime nasc = DateTime.parse(widget.user.dataNascimento);
    //print(nasc.day.toString().padLeft(2, "0"));

    if (widget.user.id_interno == null) {
      widget.user.id_interno = 0000;
    }

    return Container(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Expanded(flex: 2, child: fotoPerfil(widget.user.cpf)),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.05,
              ),
              Expanded(
                flex: 3,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Container(
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "ID FUNCIONAL:",
                            style: TextStyle(
                                fontSize:
                                    MediaQuery.of(context).size.width * SizedFont.tamanho,
                                fontFamily: 'Poppins',
                                fontWeight: FontWeight.w500,
                                color: Colors.black54),
                          ),
                          Text(
                            "${widget.user.id_interno}",
                            style: TextStyle(
                                fontSize:
                                    MediaQuery.of(context).size.width * SizedFont.tamanho,
                                fontFamily: 'Poppins',
                                fontWeight: FontWeight.w700,
                                color: Colors.black54),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "CPF:",
                            style: TextStyle(
                                fontSize:
                                    MediaQuery.of(context).size.width * SizedFont.tamanho,
                                fontFamily: 'Poppins',
                                fontWeight: FontWeight.w500,
                                color: Colors.black54),
                          ),
                          Text(
                            "${maskeredCpf.text}",
                            style: TextStyle(
                                fontSize:
                                    MediaQuery.of(context).size.width * SizedFont.tamanho,
                                fontFamily: 'Poppins',
                                fontWeight: FontWeight.w700,
                                color: Colors.black54),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "DATA DE NASCIMENTO:",
                            style: TextStyle(
                                fontSize:
                                    MediaQuery.of(context).size.width * SizedFont.tamanho,
                                fontFamily: 'Poppins',
                                fontWeight: FontWeight.w500,
                                color: Colors.black54),
                          ),
                          Text(
                            "${nasc.day.toString().padLeft(2, "0")}/${nasc.month.toString().padLeft(2, "0")}/${nasc.year}",
                            style: TextStyle(
                                fontSize:
                                    MediaQuery.of(context).size.width * SizedFont.tamanho,
                                fontFamily: 'Poppins',
                                fontWeight: FontWeight.w700,
                                color: Colors.black54),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              )
            ],
          ),
          SizedBox(
            height: MediaQuery.of(context).size.height * 0.01,
          ),
          Text(
            "NOME:",
            style: TextStyle(
                fontSize: MediaQuery.of(context).size.width * SizedFont.tamanho,
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w500,
                color: Colors.black54),
          ),
          Text(
            "${widget.user.nome}",
            style: TextStyle(
                fontSize: MediaQuery.of(context).size.width * SizedFont.tamanho,
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w700,
                color: Colors.black54),
          ),
          SizedBox(
            height: MediaQuery.of(context).size.height * 0.01,
          ),
          Text(
            "CARGO:",
            style: TextStyle(
                fontSize: MediaQuery.of(context).size.width * SizedFont.tamanho,
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w500,
                color: Colors.black54),
          ),
          Text(
            "${widget.user.categoria}",
            style: TextStyle(
                fontSize: MediaQuery.of(context).size.width * SizedFont.tamanho,
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w700,
                color: Colors.black54),
          ),
          SizedBox(
            height: MediaQuery.of(context).size.height * 0.01,
          ),
          Text(
            "LOTAÇÃO:",
            style: TextStyle(
                fontSize: MediaQuery.of(context).size.width * SizedFont.tamanho,
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w500,
                color: Colors.black54),
          ),
          Text(
            "${widget.user.lotacao}",
            style: TextStyle(
                fontSize: MediaQuery.of(context).size.width * SizedFont.tamanho,
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w700,
                color: Colors.black54),
          ),
        ],
      ),
    );
  }
}
