import 'dart:convert';

import 'package:uema_iduema/src/home/componentes/rodape-home.dart';
import 'package:uema_iduema/src/home/componentes/spinner-home.dart';
import 'package:uema_iduema/src/home/componentes/topo-home.dart';
import 'package:uema_iduema/src/home/componentes/corpo-home.dart';
import 'package:uema_iduema/src/login/login-view.dart';
import 'package:uema_iduema/src/tema/background.dart' as Tema;
import 'package:uema_iduema/src/usuario/usuario-model.dart';
import 'package:uema_iduema/src/usuario/usuario-service.dart';
import 'package:flushbar/flushbar.dart';
import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';

class HomeView extends StatefulWidget {
  final String dado; //cpf do usuário

  const HomeView({Key key, this.dado}) : super(key: key);

  @override
  HomeViewState createState() {
    return HomeViewState();
  }
}

class HomeViewState extends State<HomeView> {
  UsuarioService userService = new UsuarioService();
  UsuarioModel user = new UsuarioModel();
  Spinner spinner = new Spinner();
  bool isLoading = false;

  @override
  void initState() {
    //controleSessao();
    print("${widget.dado}");
    Future.delayed(Duration(seconds: 3), () {

      userService.retornoInfo(widget.dado).then((resultado) {
        user = resultado;
        setState(() {
          isLoading = true;
        });
      });
       
       


    });
  }

  @override
  Widget build(BuildContext context) {
    if (isLoading == false) {
      return Scaffold(
        body: SingleChildScrollView(
          child: SafeArea(
            child: Container(
              height: MediaQuery.of(context).size.height,
              width: MediaQuery.of(context).size.width,
              decoration:
                  BoxDecoration(gradient: Tema.Background.gradientePrimario),
              child: Stack(
                children: <Widget>[
                  retornaSpinner(),
                ],
              ),
            ),
          ),
        ),
      );
    }
    if (isLoading == true) {
      if (user.error != null) {
        return Scaffold(
          body: SingleChildScrollView(
            child: Container(
              height: MediaQuery.of(context).size.height,
              width: MediaQuery.of(context).size.width,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                children: <Widget>[
                  SizedBox(
                    height: MediaQuery.of(context).size.height / 2.2,
                  ),
                  SizedBox(
                    width: MediaQuery.of(context).size.width - 60,
                    child: Center(
                      child: Text(
                        "${user.error}",
                        textAlign: TextAlign.center,
                        softWrap: true,
                        style: TextStyle(
                            fontFamily: 'Poppins',
                            fontSize: 16,
                            fontWeight: FontWeight.w500),
                      ),
                    ),
                  ),
                  SizedBox(
                    height: MediaQuery.of(context).size.height / 2.5,
                  ),
                  Container(
                    width: MediaQuery.of(context).size.width - 30,
                    child: RaisedButton(
                      color: Color(0xFF113A68),
                      splashColor: Color(0xFF113A68),
                      disabledColor: Color(0xFF113A68),
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(10)),
                      child: Text(
                        "SAIR",
                        style: TextStyle(
                            fontFamily: 'Poppins',
                            fontSize: 18,
                            color: Colors.white,
                            fontWeight: FontWeight.w500),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        );
      }

      if (user.error == null) {
        return Scaffold(
          body: SingleChildScrollView(
            child: SafeArea(
              child: Container(
                //width: MediaQuery.of(context).size.width,
                decoration:
                    BoxDecoration(gradient: Tema.Background.gradientePrimario),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: <Widget>[
                    TopoHome(),
                    CorpoHome(
                      user: user,
                    ),
                    RodapeHome(),
                    botaoValidar(),
                    SizedBox(
                      height: 10,
                    ),
                    botaoSair(),
                    
                    
                    SizedBox(
                      height: MediaQuery.of(context).size.height * 0.025,
                    )
                  ],
                ),
              ),
            ),
          ),
        );
      }
    }
  }

  retornaSpinner() {
    return Center(
      child: spinner,
    );
  }

  controleSessao() {
    Future.delayed(Duration(seconds: 5), () {
      Flushbar(
        message: "Sua sessão irá expirar em 5 segundos",
        icon: Icon(
          Icons.info_outline,
          color: Colors.blue.shade600,
        ),
        leftBarIndicatorColor: Colors.blue.shade600,
        duration: Duration(seconds: 3),
      )..show(context);
    });

    Future.delayed(Duration(seconds: 10), () {
      return showDialog(
          context: context,
          builder: (context) {
            return AlertDialog(
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(10)),
              backgroundColor: Colors.white,
              content: Text("Sua sessão expirou.",
                  style: TextStyle(
                      fontFamily: 'Poppins',
                      fontSize: 16,
                      fontWeight: FontWeight.w500)),
              actions: <Widget>[
                new FlatButton(
                    onPressed: () {
                      Navigator.push(context,
                          MaterialPageRoute(builder: (context) => LoginView()));
                    },
                    child: Text("OK",
                        style: TextStyle(
                            fontFamily: 'Poppins',
                            fontSize: 14,
                            fontWeight: FontWeight.w600))),
              ],
            );
          });
    });
  }

  botaoSair() {
    return Container(
      height: MediaQuery.of(context).size.height * 0.05,
      width: MediaQuery.of(context).size.width - 20,
      child: RaisedButton(
        color: Color(0xFF113A68),
        splashColor: Color(0xFF113A68),
        disabledColor: Color(0xFF113A68),
        onPressed: () {
          Navigator.pop(context);
        },
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(10)),
        child: Text(
          "SAIR",
          style: TextStyle(
              fontFamily: 'Poppins',
              fontSize: MediaQuery.of(context).size.width * 0.05,
              color: Colors.white,
              fontWeight: FontWeight.w700),
        ),
      ),
    );
  }

  botaoValidar() {

   var cpfUser = user.cpf;
   var cpfUTF8 = utf8.encode(cpfUser);
   var cpfBase64 = base64.encode(cpfUTF8);

    return Container(
      height: MediaQuery.of(context).size.height * 0.05,
      width: MediaQuery.of(context).size.width - 20,
      child: RaisedButton(
        color: Colors. transparent,
        /* splashColor: Color(0xFF113A68),
        disabledColor: Color(0xFF113A68), */
        onPressed: () async {
          if (await canLaunch("https://www.progep.uema.br/?page_id=776&data=$cpfBase64")) {
            await (launch("https://www.progep.uema.br/?page_id=776&data=$cpfBase64"));
          }
        },
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10),
            side: BorderSide(color: Color(0xFF113A68))),
        child: Text(
          "VALIDAR",
          style: TextStyle(
              fontFamily: 'Poppins',
              fontSize: MediaQuery.of(context).size.width * 0.05,
              color: Colors.white,
              fontWeight: FontWeight.w700),
        ),
      ),
    );
  }
}
