import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_masked_text/flutter_masked_text.dart';
import 'package:uema_iduema/src/login/componentes/rodape-login.dart';
import 'package:uema_iduema/src/login/componentes/verificador-login.dart';
import 'package:uema_iduema/src/login/login-model.dart';
import 'package:uema_iduema/src/login/login-service.dart';
import 'package:uema_iduema/src/tema/background.dart' as Tema;

/*
Classe de visualização da Página Inicial
 */

class LoginView extends StatefulWidget {
  @override
  LoginViewState createState() {
    return LoginViewState();
  }
}

class LoginViewState extends State<LoginView> {
  LoginModel loginModel = new LoginModel();
  LoginService loginService = new LoginService();
  VerificadorLogin exceptions = new VerificadorLogin();
  final GlobalKey<FormState> _formKey = new GlobalKey<FormState>();
  var loginController = new MaskedTextController(mask: '000.000.000-00');
  TextEditingController senhaController = TextEditingController();
  bool _validate = false;
  String login, senha;

  _validarcpf() {}

  _sendForm() {
    if (_formKey.currentState.validate()) {
      _formKey.currentState.save();
      login = loginController.text.replaceAll(new RegExp(r'[.\-]'), '');
      senha = senhaController.text;

      loginModel.login = login;
      loginModel.senha = senha;
      //print("login: ${loginModel.login},senha: ${loginModel.senha}");
      Future<int> statusConexao = loginService.checaLogin(loginModel);

      statusConexao.then((resultado) {
        exceptions.verificador(resultado, loginModel.login, context);
      });

      setState(() {
        loginController.text = "";
        senhaController.text = "";
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: GestureDetector(
        onTap: (){
          FocusScope.of(context).unfocus();
        },
        child: SingleChildScrollView(
          child: Container(
            height: MediaQuery.of(context).size.height,
            decoration: BoxDecoration(
              gradient: Tema.Background.gradientePrimario,
            ),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                carregarLogo(),
                SizedBox(
                  height: MediaQuery.of(context).size.width * 0.05,
                ),
                carregarLogin(),
                SizedBox(
                  height: MediaQuery.of(context).size.width * 0.05,
                ),
                RodapeLogin()
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget carregarLogo() {
    return new Center(
      child: new Image(
        height: MediaQuery.of(context).size.height * 0.3,
        image: new AssetImage("assets/img/logo_idUema.png"),
      ),
    );
  }

  Widget carregarLogin() {
    return new Center(
        child: new Container(
      height: MediaQuery.of(context).size.height * 0.3,
      child: new Form(
        key: _formKey,
        autovalidate: _validate,
        child: _formUI(),
      ),
    ));
  }

  Widget _formUI() {
    double largura = (MediaQuery.of(context).size.width - 60);

    return new Column(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: <Widget>[ 
        new SizedBox(
          height: MediaQuery.of(context).size.height * 0.08,
          width: largura,
          child: new TextFormField(
            style:
                TextStyle(fontSize: MediaQuery.of(context).size.width * 0.05),
            controller: loginController,
            decoration: new InputDecoration(
              enabledBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(10),
                borderSide: const BorderSide(color: Colors.white),
              ),
              focusedBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(10),
                borderSide: const BorderSide(color: Colors.white),
              ),
              fillColor: Colors.white,
              filled: true,
              contentPadding:
                  new EdgeInsets.all(MediaQuery.of(context).size.width * 0.025),
              hintText: 'CPF',
              hintStyle: TextStyle(
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w600,
              ),
            ),
            inputFormatters: [
              new LengthLimitingTextInputFormatter(15),
            ],
            keyboardType: TextInputType.number,
            validator: (text) {
              if (text == "") return "Preencha o campo acima!";
            },
          ),
        ),
        new SizedBox(
          height: MediaQuery.of(context).size.height * 0.08,
          width: largura,
          child: new TextFormField(
            style:
                TextStyle(fontSize: MediaQuery.of(context).size.width * 0.05),
            controller: senhaController,
            obscureText: true,
            decoration: new InputDecoration(
              enabledBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(10),
                borderSide: const BorderSide(color: Colors.white),
              ),
              focusedBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(10),
                borderSide: const BorderSide(color: Colors.white),
              ),
              fillColor: Colors.white,
              filled: true,
              contentPadding:
                  new EdgeInsets.all(MediaQuery.of(context).size.width * 0.025),
              hintText: 'SENHA',
              hintStyle: TextStyle(
                fontFamily: 'Poppins',
                fontWeight: FontWeight.w600,
              ),
            ),
            validator: (text) {
              if (text == "") return "Preencha o campo acima!";
            },
          ),
        ),
        new SizedBox(
          height: MediaQuery.of(context).size.height * 0.07,
          width: largura,
          child: new GestureDetector(
            child: new Card(
                color: Color(0xFF113A68),
                shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10)),
                child: Center(
                  child: Text(
                    "LOGIN",
                    textAlign: TextAlign.center,
                    style: TextStyle(
                      fontFamily: 'Poppins',
                      color: Colors.white,
                      fontSize: MediaQuery.of(context).size.width * 0.06,
                      fontWeight: FontWeight.w600,
                    ),
                  ),
                )),
            onTap: () {
              _sendForm();
            },
          ),
        )
      ],
    );
  }
}
